@@ -10,6 +10,6 @@ my $urlbase = shift || die "Base URL missing\n";
 my $dir = shift || die "Dir to scan missing\n";
 
 my $pod = MP3::Podcast->new($dirbase,$urlbase);
-my $rss = $pod->podcast( $dir, "Podcast test" );
+my $rss = $pod->podcast( $dir, "Prueba podcast" );
 
 print $rss->as_string;
